===========================
``psyclone.core.signature``
===========================

.. automodule:: psyclone.core.signature

   .. contents::
      :local:

.. currentmodule:: psyclone.core.signature


Classes
=======

- :py:class:`Signature`:
  Given a variable access of the form ``a(i,j)%b(k,l)%c``, the signature


.. autoclass:: Signature
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Signature
      :parts: 1
